| grad_iid | R Documentation |
Computes gradient of Q-function with respect to log(c(lambda,phi)) for EM algorithm from Cao et al. (2000) for their locally IID model.
grad_iid(logtheta, c, M, rdiag, epsilon)
logtheta |
numeric vector (length k+1) of log(lambda) (1:k) and log(phi) (last entry) |
c |
power parameter in model of Cao et al. (2000) |
M |
matrix (n x k) of conditional expectations for OD flows, one time per row |
rdiag |
numeric vector (length k) containing diagonal of conditional covariance matrix R |
epsilon |
numeric nugget to add to diagonal of covariance for numerical stability |
numeric vector of same length as logtheta containing calculated gradient
J. Cao, D. Davis, S. Van Der Viel, and B. Yu. Time-varying network tomography: router link data. Journal of the American Statistical Association, 95:1063-75, 2000.
Other CaoEtAl:
Q_iid(),
Q_smoothed(),
R_estep(),
grad_smoothed(),
locally_iid_EM(),
m_estep(),
phi_init(),
smoothed_EM()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.