| phi_init | R Documentation |
Uses a crude estimator to get a starting point for phi in the model of Cao et al. (2000).
phi_init(Y, A, lambda0, c)
Y |
matrix (n x k) of observed link loads over time |
A |
routing matrix (m x k) |
lambda0 |
numeric vector (length k) of initial guesses for lambda |
c |
power parameter in model of Cao et al. (2000) |
numeric starting value for phi
J. Cao, D. Davis, S. Van Der Viel, and B. Yu. Time-varying network tomography: router link data. Journal of the American Statistical Association, 95:1063-75, 2000.
Other CaoEtAl:
Q_iid(),
Q_smoothed(),
R_estep(),
grad_iid(),
grad_smoothed(),
locally_iid_EM(),
m_estep(),
smoothed_EM()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.